@@ -1,5 +1,5 @@
-/*
- * Copyright (c) 1995-2007, Index Data
+/* This file is part of the YAZ toolkit.
+ * Copyright (C) 1995-2008 Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -24,7 +24,6 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-/* $Id: marcdisp.h,v 1.30 2007-12-17 20:59:30 adam Exp $ */
 
 /**
  * \file marcdisp.h
@@ -71,9 +70,12 @@ YAZ_EXPORT void yaz_marc_xml(yaz_marc_t mt, int xmlmode);
 /** \brief Output format: check only (no marc output) */
 #define YAZ_MARC_CHECK  6
 
-/** \brief supply iconv handle for character set conversion .. */
+/** \brief set iconv handle for character set conversion .. */
 YAZ_EXPORT void yaz_marc_iconv(yaz_marc_t mt, yaz_iconv_t cd);
 
+/** \brief supply iconv handle for character set conversion .. */
+YAZ_EXPORT yaz_iconv_t yaz_marc_get_iconv(yaz_marc_t mt);
+
 /** \brief set debug level 
     \param mt handle
     \param level level, where 0=lowest, 1 more debug, 2 even more 
@@ -160,6 +162,7 @@ int yaz_marc_read_line(yaz_marc_t mt,
                        void (*ungetbyte)(int b, void *client_data),
                        void *client_data);
 
+#if YAZ_HAVE_XML2
 /** \brief parses MARCXML/MarcXchange record from xmlNode pointer 
     \param mt handle
     \param ptr is a pointer to root xml node 
@@ -167,6 +170,7 @@ int yaz_marc_read_line(yaz_marc_t mt,
     Returns 0=OK, -1=ERROR
 */
 YAZ_EXPORT int yaz_marc_read_xml(yaz_marc_t mt, const xmlNode *ptr);
+#endif
 
 /** \brief writes record in line format
     \param mt handle
@@ -212,6 +216,7 @@ YAZ_EXPORT int yaz_marc_write_iso2709(yaz_marc_t mt, WRBUF wrbuf);
 */  
 YAZ_EXPORT int yaz_marc_write_mode(yaz_marc_t mt, WRBUF wrbuf);
 
+#if YAZ_HAVE_XML2
 /** \brief writes MARC record as libxml2 tree
     \param mt handle
     \param root_ptr pointer to record node
@@ -226,6 +231,7 @@ int yaz_marc_write_xml(yaz_marc_t mt, xmlNode **root_ptr,
                        const char *ns, 
                        const char *format,
                        const char *type);
+#endif
 
 /** \brief sets leader spec (for modifying bytes in 24 byte leader)
     \param mt handle
@@ -296,6 +302,7 @@ void yaz_marc_add_controlfield(yaz_marc_t mt, const char *tag,
                                const char *data, size_t data_len);
 
 
+#if YAZ_HAVE_XML2
 /** \brief adds controlfield to MARC structure using xml Nodes
     \param mt handle
     \param ptr_tag value of tag (TEXT xmlNode)
@@ -304,7 +311,7 @@ void yaz_marc_add_controlfield(yaz_marc_t mt, const char *tag,
 YAZ_EXPORT
 void yaz_marc_add_controlfield_xml(yaz_marc_t mt, const xmlNode *ptr_tag,
                                    const xmlNode *ptr_data);
-
+#endif
 
 /** \brief adds datafield to MARC structure using strings
     \param mt handle
@@ -316,6 +323,7 @@ YAZ_EXPORT
 void yaz_marc_add_datafield(yaz_marc_t mt, const char *tag,
                             const char *indicator, size_t indicator_len);
 
+#if YAZ_HAVE_XML2
 /** \brief adds datafield to MARC structure using xml Nodes
     \param mt handle
     \param ptr_tag value of tag (TEXT xmlNode)
@@ -325,7 +333,7 @@ void yaz_marc_add_datafield(yaz_marc_t mt, const char *tag,
 YAZ_EXPORT
 void yaz_marc_add_datafield_xml(yaz_marc_t mt, const xmlNode *ptr_tag,
                                 const char *indicator, size_t indicator_len);
-
+#endif
 
 /** \brief returns memory for MARC handle
     \param mt handle
@@ -369,7 +377,7 @@ YAZ_EXPORT void yaz_opac_decode_wrbuf(yaz_marc_t mt, Z_OPACRecord *r, WRBUF wrbu
 
 /** \brief flushes records
     \param mt handle
-    \param wrbuf WRBUF for output
+    \param wr WRBUF for output
     \retval 0 OK
     \retval -1 ERROR
 */  
